==> estateplat-common-1.2.4-20201112.094910-501-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxWjwCszm.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-卫健委-出生证明
 */
@Table(name = "xxgx_wjw_cszm")
public class XxgxWjwCszm {
    @Id
    private String cszmid;//出生证明id
    private String cszmbh;//出生证明编号
    private String mqxm;//母亲姓名
    private String mqzjhm;//母亲证件号码
    private String xsexm;//新生儿姓名
    private String xsexbbm;//新生儿性别编码
    private String xsexb;//新生儿性别
    private String csdq;//出生地区
    private Date cssj;//出生时间
    private String csyxzmbh;//出生医学证明编号
    private String fqxm;//父亲姓名
    private String qzjhm;//父亲证件号码
    private String proid;//项目ID

    public String getCszmid() {
        return cszmid;
    }

    public void setCszmid(String cszmid) {
        this.cszmid = cszmid;
    }

    public String getCszmbh() {
        return cszmbh;
    }

    public void setCszmbh(String cszmbh) {
        this.cszmbh = cszmbh;
    }

    public String getMqxm() {
        return mqxm;
    }

    public void setMqxm(String mqxm) {
        this.mqxm = mqxm;
    }

    public String getMqzjhm() {
        return mqzjhm;
    }

    public void setMqzjhm(String mqzjhm) {
        this.mqzjhm = mqzjhm;
    }

    public String getXsexm() {
        return xsexm;
    }

    public void setXsexm(String xsexm) {
        this.xsexm = xsexm;
    }

    public String getXsexbbm() {
        return xsexbbm;
    }

    public void setXsexbbm(String xsexbbm) {
        this.xsexbbm = xsexbbm;
    }

    public String getXsexb() {
        return xsexb;
    }

    public void setXsexb(String xsexb) {
        this.xsexb = xsexb;
    }

    public String getCsdq() {
        return csdq;
    }

    public void setCsdq(String csdq) {
        this.csdq = csdq;
    }

    public Date getCssj() {
        return cssj;
    }

    public void setCssj(Date cssj) {
        this.cssj = cssj;
    }

    public String getCsyxzmbh() {
        return csyxzmbh;
    }

    public void setCsyxzmbh(String csyxzmbh) {
        this.csyxzmbh = csyxzmbh;
    }

    public String getFqxm() {
        return fqxm;
    }

    public void setFqxm(String fqxm) {
        this.fqxm = fqxm;
    }

    public String getQzjhm() {
        return qzjhm;
    }

    public void setQzjhm(String qzjhm) {
        this.qzjhm = qzjhm;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20220113.030814-968-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxWjwCszm.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-卫健委-出生证明
 */
@Table(name = "xxgx_wjw_cszm")
public class XxgxWjwCszm {
    @Id
    private String cszmid;//出生证明id
    private String cszmbh;//出生证明编号
    private String mqxm;//母亲姓名
    private String mqzjhm;//母亲证件号码
    private String xsexm;//新生儿姓名
    private String xsexbbm;//新生儿性别编码
    private String xsexb;//新生儿性别
    private String csdq;//出生地区
    private Date cssj;//出生时间
    private String csyxzmbh;//出生医学证明编号
    private String fqxm;//父亲姓名
    private String fqzjhm;//父亲证件号码
    private String proid;//项目ID

    public String getCszmid() {
        return cszmid;
    }

    public void setCszmid(String cszmid) {
        this.cszmid = cszmid;
    }

    public String getCszmbh() {
        return cszmbh;
    }

    public void setCszmbh(String cszmbh) {
        this.cszmbh = cszmbh;
    }

    public String getMqxm() {
        return mqxm;
    }

    public void setMqxm(String mqxm) {
        this.mqxm = mqxm;
    }

    public String getMqzjhm() {
        return mqzjhm;
    }

    public void setMqzjhm(String mqzjhm) {
        this.mqzjhm = mqzjhm;
    }

    public String getXsexm() {
        return xsexm;
    }

    public void setXsexm(String xsexm) {
        this.xsexm = xsexm;
    }

    public String getXsexbbm() {
        return xsexbbm;
    }

    public void setXsexbbm(String xsexbbm) {
        this.xsexbbm = xsexbbm;
    }

    public String getXsexb() {
        return xsexb;
    }

    public void setXsexb(String xsexb) {
        this.xsexb = xsexb;
    }

    public String getCsdq() {
        return csdq;
    }

    public void setCsdq(String csdq) {
        this.csdq = csdq;
    }

    public Date getCssj() {
        return cssj;
    }

    public void setCssj(Date cssj) {
        this.cssj = cssj;
    }

    public String getCsyxzmbh() {
        return csyxzmbh;
    }

    public void setCsyxzmbh(String csyxzmbh) {
        this.csyxzmbh = csyxzmbh;
    }

    public String getFqxm() {
        return fqxm;
    }

    public void setFqxm(String fqxm) {
        this.fqxm = fqxm;
    }

    public String getFqzjhm() {
        return fqzjhm;
    }

    public void setFqzjhm(String fqzjhm) {
        this.fqzjhm = fqzjhm;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}
